@@ -116,25 +116,8 @@ class SpannerConnection:
 class SpannerApi(SpannerReadApi, SpannerWriteApi):
   """Class that handles reading from and writing to Spanner tables."""
 
-  def __init__(self, connection: SpannerConnection,
-               retry=google.api_core.gapic_v1.method.DEFAULT,
-               timeout=google.api_core.gapic_v1.method.DEFAULT,
-               ):
-    """
-    :param connection:
-    :param retry: If specified, this is set as the default value for retries in all read-only queries
-    :param timeout: If specified, this is set as the default value for timeout in all read-only queries. However,
-      to actually change timeout, you need to modify the retry parameter.
-    """
+  def __init__(self, connection: SpannerConnection):
     self._spanner_connection = connection
-    self._retry = retry
-    self._timeout = timeout
-
-  def run_read_only(self, method: Callable[..., CallableReturn], *args: Any,
-                    **kwargs: Any) -> CallableReturn:
-    kwargs.setdefault("retry", self._retry)
-    kwargs.setdefault("timeout", self._timeout)
-    return super().run_read_only(method, *args, **kwargs)
 
   @property
   def _connection(self):
